#define MICROPY_HW_BOARD_NAME               "TinyS3"
#define MICROPY_HW_MCU_NAME                 "ESP32-S3-FN8"
#define MICROPY_PY_NETWORK_HOSTNAME_DEFAULT "TinyS3"

#define MICROPY_HW_I2C0_SCL                 (9)
#define MICROPY_HW_I2C0_SDA                 (8)

#define MICROPY_HW_SPI1_MOSI                (35)
#define MICROPY_HW_SPI1_MISO                (37)
#define MICROPY_HW_SPI1_SCK                 (36)

#define MICROPY_HW_USB_VID 0x303A
#define MICROPY_HW_USB_PID 0x80D1
#define MICROPY_HW_USB_MANUFACTURER_STRING "Unexpected Maker"
#define MICROPY_HW_USB_PRODUCT_FS_STRING "TinyS3"
